@@ -36,6 +36,7 @@ from plotly_helper.neuron_viewer import NeuronBuilder
 
 from morphology_workflows.marker_helper import Marker
 from morphology_workflows.marker_helper import MarkerSet
+from morphology_workflows.utils import disable_loggers
 from morphology_workflows.utils import is_morphology
 
 L = logging.getLogger(__name__)
@@ -53,6 +54,12 @@ def collect(row, data_dir, morph_path_col="morph_path"):
         )
     is_morph, ext = is_morphology(row[morph_path_col])
     if is_morph:
+        if " " in row.name:
+            return ValidationResult(
+                is_valid=False,
+                comment=f"{row[morph_path_col]} has spaces in its name, which is not supported.",
+                morph_path=None,
+            )
         full_new_morph_path = str(data_dir / row.name) + ext
         shutil.copy(row[morph_path_col], full_new_morph_path)
         return ValidationResult(is_valid=True, morph_path=full_new_morph_path)
@@ -135,11 +142,50 @@ def plot_markers(row, data_dir, with_plotly=True):
     return ValidationResult(is_valid=True, plot_marker_path=plot_path)
 
 
-def sanitize(row, data_dir):
-    """Sanitize morphologies."""
+def _reconnect_to_soma(m):
+    """Reconnect a neurite to soma if it is not."""
+
+    def _copy(section, section_base):
+        """Recursively copy downstream from section_base to section."""
+        for base_child in section_base.children:
+            section.append_section(base_child)
+        for child, base_child in zip(section.children, section_base.children):
+            _copy(child, base_child)
+
+    for root in m.root_sections:
+        for section in root.iter():
+            if section.type != root.type:
+                L.warning("We found root sections not at soma, reconnecting.")
+                new_sec = m.append_root_section(section)
+                _copy(new_sec, section)
+                m.delete_section(section, recursive=True)
+                return True
+    return False
+
+
+def sanitize(row, data_dir, ensure_roots_at_soma=True):
+    """Sanitize morphologies.
+
+    With `ensure_roots_at_soma` we disconnect neurites not at the soma and connect
+    at the soma. This may happen for dendrite bearing axons morphologies in .swc format.
+    Weirdness may happen, for example upon converting to .asc, the axon will become a basal.
+    """
     new_morph_path = data_dir / Path(row.morph_path).name
+    m = Morphology(row.morph_path)
+    if ensure_roots_at_soma:
+        retry = True
+        while retry:
+            if not _reconnect_to_soma(m):
+                # if sanitize fails for another reason, we let it crash after
+                break
+            try:
+                _sanitize(m, new_morph_path)
+                retry = False
+            except CorruptedMorphology:
+                retry = True
+
     try:
-        _sanitize(row.morph_path, new_morph_path)
+        _sanitize(m, new_morph_path)
     except CorruptedMorphology as exc:
         return ValidationResult(is_valid=False, comment=exc, morph_path=None)
     return ValidationResult(is_valid=True, morph_path=new_morph_path)
@@ -168,7 +214,7 @@ def _add_soma(morph, soma_type="spherical"):
             angle_order = np.argsort(angles)
 
             morph.soma.points = root_points[angle_order]
-            morph.soma.diameters = np.zeros(len(root_points), dtype=np.float)
+            morph.soma.diameters = np.zeros(len(root_points), dtype=float)
             L.info("Adding a contour mock soma around %s with %s points.", center, len(root_points))
 
     return morph
@@ -477,7 +523,7 @@ def align(
             raise ValueError(
                 "Provide a custom_orientation_json_path parameter when method=='custom'"
             )
-        with open(custom_orientation_json_path, "r") as orient_file:
+        with open(custom_orientation_json_path, "r", encoding="utf-8") as orient_file:
             orient_dict = json.load(orient_file)
         if row.name in orient_dict:
             direction = orient_dict[row.name]
@@ -632,7 +678,9 @@ def plot_morphology(row, data_dir, with_plotly=True, realistic_diameters=True):
         bbox = np.array([[-1000, -1000, 1000], [1000, 1000, 1000]])
 
     plot_path = (data_dir / row.name).with_suffix(".pdf")
-    with PdfPages(plot_path) as pdf:
+    with disable_loggers("matplotlib.font_manager", "matplotlib.backends.backend_pdf"), PdfPages(
+        plot_path
+    ) as pdf:
         for plane, axis in {"xy": [0, 1], "xz": [0, 2], "yz": [1, 2]}.items():
             plt.figure()
             view.plot_morph(
